==> 3.5.12-core.tar: kdeadmin/kdat/IndexDlg.h <==
// KDat - a tar-based DAT archiver
// Copyright (C) 1998-2000  Sean Vyain, svyain@mail.tds.net
// Copyright (C) 2001-2002  Lawrence Widman, kdat@cardiothink.com
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

#ifndef _IndexDlg_h_
#define _IndexDlg_h_

#include <tqdialog.h>
#include <tqptrlist.h>

#include "Range.h"

class TQLabel;
class TQPushButton;

class Archive;
class File;
class LoggerWidget;
class Tape;
class TarParser;

/**
 * @short Status dialog for recreating a tape index.
 */
class IndexDlg : public TQDialog {
    Q_OBJECT
    TarParser*          _tarParser;
    Tape*               _tape;
    Archive*            _archive;
    TQString             _leftover;
    TQLabel*             _elapsedTime;
    TQLabel*             _kbytesRead;
    TQLabel*             _transferRate;
    TQLabel*             _archives;
    TQLabel*             _files;
    TQLabel*             _totalFiles;
    LoggerWidget*       _log;
    TQPushButton*        _ok;
    TQPushButton*        _save;
    TQPushButton*        _abort;
    int                 _startTime;
    float               _totalKBytes;
    int                 _archiveCount;
    int                 _fileCount;
    int                 _totalFileCount;
    bool                _aborted;
    int                 _numFiles;

    int     _fileSize;
    int     _fileMTime;
    int     _fileStartRecord;
    TQString _fileName;

    void updateStats();
private slots:
    void slotOK();
    void slotAbort();
    void slotEntry( const TQString & name, int size, int mtime, int record );
protected:
    void show();
    void timerEvent( TQTimerEvent* e );
public:
    /**
     * Create a new tape index dialog.
     *
     * @param tape   A pointer to the empty tape index to fill in.
     * @param parent The parent widget for this dialog.
     * @param name   The name of this dialog.
     */
    IndexDlg( Tape* tape, TQWidget* parent = 0, const char* name = 0 );

    /**
     * Destroy the tape index dialog.
     */
    ~IndexDlg();
};

#endif

==> 3.5.13-core.tar: kdeadmin/kdat/IndexDlg.h <==
// KDat - a tar-based DAT archiver
// Copyright (C) 1998-2000  Sean Vyain, svyain@mail.tds.net
// Copyright (C) 2001-2002  Lawrence Widman, kdat@cardiothink.com
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

#ifndef _IndexDlg_h_
#define _IndexDlg_h_

#include <tqdialog.h>
#include <tqptrlist.h>

#include "Range.h"

class TQLabel;
class TQPushButton;

class Archive;
class File;
class LoggerWidget;
class Tape;
class TarParser;

/**
 * @short tqStatus dialog for recreating a tape index.
 */
class IndexDlg : public TQDialog {
    Q_OBJECT
  TQ_OBJECT
    TarParser*          _tarParser;
    Tape*               _tape;
    Archive*            _archive;
    TQString             _leftover;
    TQLabel*             _elapsedTime;
    TQLabel*             _kbytesRead;
    TQLabel*             _transferRate;
    TQLabel*             _archives;
    TQLabel*             _files;
    TQLabel*             _totalFiles;
    LoggerWidget*       _log;
    TQPushButton*        _ok;
    TQPushButton*        _save;
    TQPushButton*        _abort;
    int                 _startTime;
    float               _totalKBytes;
    int                 _archiveCount;
    int                 _fileCount;
    int                 _totalFileCount;
    bool                _aborted;
    int                 _numFiles;

    int     _fileSize;
    int     _fileMTime;
    int     _fileStartRecord;
    TQString _fileName;

    void updateStats();
private slots:
    void slotOK();
    void slotAbort();
    void slotEntry( const TQString & name, int size, int mtime, int record );
protected:
    void show();
    void timerEvent( TQTimerEvent* e );
public:
    /**
     * Create a new tape index dialog.
     *
     * @param tape   A pointer to the empty tape index to fill in.
     * @param parent The parent widget for this dialog.
     * @param name   The name of this dialog.
     */
    IndexDlg( Tape* tape, TQWidget* parent = 0, const char* name = 0 );

    /**
     * Destroy the tape index dialog.
     */
    ~IndexDlg();
};

#endif
